import type { DescribeChangeSetOutput as DescribeChangeSet } from '@aws-sdk/client-cloudformation';
import * as types from './diff/types';
export * from './diff/types';
export type DescribeChangeSetOutput = DescribeChangeSet;
/**
 * Compare two CloudFormation templates and return semantic differences between them.
 *
 * @param currentTemplate the current state of the stack.
 * @param newTemplate     the target state of the stack.
 * @param changeSet       the change set for this stack.
 *
 * @returns a +types.TemplateDiff+ object that represents the changes that will happen if
 *      a stack which current state is described by +currentTemplate+ is updated with
 *      the template +newTemplate+.
 */
export declare function fullDiff(currentTemplate: {
    [key: string]: any;
}, newTemplate: {
    [key: string]: any;
}, changeSet?: DescribeChangeSetOutput, isImport?: boolean): types.TemplateDiff;
export declare function diffTemplate(currentTemplate: {
    [key: string]: any;
}, newTemplate: {
    [key: string]: any;
}): types.TemplateDiff;
